summaryrefslogtreecommitdiffstats
path: root/isys/isys.c
diff options
context:
space:
mode:
Diffstat (limited to 'isys/isys.c')
-rw-r--r--isys/isys.c5
1 files changed, 3 insertions, 2 deletions
diff --git a/isys/isys.c b/isys/isys.c
index f51f0f324..36c6f67e3 100644
--- a/isys/isys.c
+++ b/isys/isys.c
@@ -1372,10 +1372,11 @@ static PyObject * doIsScsiRemovable(PyObject * s, PyObject * args) {
/* look at byte 1, bit 7 for removable flag */
if (!(rc = ioctl(fd, SCSI_IOCTL_SEND_COMMAND, &inq))) {
if (inq.cmd[1] & (1 << 7)) {
/* XXX check the vendor, if it's DELL or HP it could be
an adaptec perc RAID (aacraid) device */
if ((!strncmp (inq.cmd + 8, "DELL", 4))
- || (!strncmp (inq.cmd + 8, "HP", 2))) {
+ || (!strncmp (inq.cmd + 8, "HP", 2))
+ || (!strncmp (inq.cmd + 8, "ADAPTEC", 7))) {
rc = 0;
} else
rc = 1;
@@ -1372,10 +1372,11 @@ static PyObject * doIsScsiRemovable(PyObject * s, PyObject * args) {
if (!(rc = ioctl(fd, SCSI_IOCTL_SEND_COMMAND, &inq))) {
if (inq.cmd[1] & (1 << 7)) {
- /* XXX check the vendor, if it's DELL or HP it could be
+ /* XXX check the vendor, if it's DELL, HP, or ADAPTEC it could be
an adaptec perc RAID (aacraid) device */
if ((!strncmp (inq.cmd + 8, "DELL", 4))